% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/CreatePathPlot.R
\name{CreatePathPlot}
\alias{CreatePathPlot}
\title{Create the fitted sample path plot based on the results from FPCA().}
\usage{
CreatePathPlot(
  fpcaObj,
  subset,
  K = NULL,
  inputData = fpcaObj[["inputData"]],
  showObs = !is.null(inputData),
  obsOnly = FALSE,
  showMean = FALSE,
  derOptns = list(p = 0),
  ...
)
}
\arguments{
\item{fpcaObj}{Returned object from FPCA().}

\item{subset}{A vector of indices or a logical vector for subsetting the
observations.}

\item{K}{The number of components to reconstruct the fitted sample paths.}

\item{inputData}{A list of length 2 containing the sparse/dense
(unsupported yet) observations. \code{inputData} needs to contain two
fields: \code{Lt} for a list of time points and \code{Ly} for a list of
observations. Default to the `inputData` field within `fpcaObj`.}

\item{showObs}{Whether to plot the original observations for each subject.}

\item{obsOnly}{Whether to show only the original curves.}

\item{showMean}{Whether to plot the mean function as a bold solid curve.}

\item{derOptns}{A list of options to control derivation parameters; see `fitted.FPCA'. (default = NULL)}

\item{...}{other arguments passed into matplot for plotting options}
}
\description{
Create the fitted sample path plot based on the results from FPCA().
}
\examples{
set.seed(1)
n <- 20
pts <- seq(0, 1, by=0.05)
sampWiener <- Wiener(n, pts)
sampWiener <- Sparsify(sampWiener, pts, 10)
res <- FPCA(sampWiener$Ly, sampWiener$Lt, 
            list(dataType='Sparse', error=FALSE, kernel='epan',
            verbose=TRUE))
CreatePathPlot(res, subset=1:5)

# CreatePathPlot has a lot of usages:
\donttest{
CreatePathPlot(res)
CreatePathPlot(res, 1:20)
CreatePathPlot(res, 1:20, showObs=FALSE)
CreatePathPlot(res, 1:20, showMean=TRUE, showObs=FALSE)
CreatePathPlot(res, 1:20, obsOnly=TRUE)
CreatePathPlot(res, 1:20, obsOnly=TRUE, showObs=FALSE)
CreatePathPlot(inputData=sampWiener, subset=1:20, obsOnly=TRUE)}

}
