% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/FVPA.R
\name{FVPA}
\alias{FVPA}
\title{Functional Variance Process Analysis for dense functional data}
\usage{
FVPA(y, t, q = 0.1, optns = list(error = TRUE, FVEthreshold = 0.9))
}
\arguments{
\item{y}{A list of \emph{n} vectors containing the observed values for each individual. Missing values specified by \code{NA}s are supported for dense case (\code{dataType='dense'}).}

\item{t}{A list of \emph{n} vectors containing the observation time points for each individual corresponding to y.}

\item{q}{A scalar defining the percentile of the pooled sample residual sample used for adjustment before taking log (default: 0.1).}

\item{optns}{A list of options control parameters specified by \code{list(name=value)}; by default: 'error' has to be TRUE, 'FVEthreshold' is set to 0.90. See `Details in ?FPCA'.}
}
\value{
A list containing the following fields:
\item{sigma2}{Variance estimator of the functional variance process.} 
\item{fpcaObjY}{FPCA object for the original data.} 
\item{fpcaObjR}{FPCA object for the functional variance process associated with the original data.}
}
\description{
Functional Variance Process Analysis for dense functional data
}
\examples{
set.seed(1)
n <- 25
pts <- seq(0, 1, by=0.01)
sampWiener <- Wiener(n, pts)
# Data have to dense for FVPA to be relevant!
sampWiener <- Sparsify(sampWiener, pts, 101) 
fvpaObj <- FVPA(sampWiener$Ly, sampWiener$Lt)
}
\references{
\cite{Hans-Georg Müller, Ulrich Stadtmüller and Fang Yao, "Functional variance processes." Journal of the American Statistical Association 101 (2006): 1007-1018}
}
